@@ -1,6 +1,7 @@
 import os
 import sys
 import matplotlib.pyplot as plt
+
 import numpy as np
 import random
 import time
@@ -67,9 +68,12 @@ class MainWindow(QtG.QMainWindow):
         import_box_folder = QtG.QAction("Import box files", self)
         import_box_folder.triggered.connect(self.load_box_files)
 
-        write_box_files = QtG.QAction("Write box files", self)
+        write_box_files = QtG.QAction("BOX", self)
         write_box_files.triggered.connect(self.write_box_files)
 
+        write_star_files = QtG.QAction("STAR", self)
+        write_star_files.triggered.connect(self.write_star_files)
+
         self.show_confidence_histogram_action = QtG.QAction(
             "Confidence histogram", self
         )
@@ -88,7 +92,10 @@ class MainWindow(QtG.QMainWindow):
         self.fileMenu = self.mainMenu.addMenu("&File")
         self.fileMenu.addAction(open_image_folder)
         self.fileMenu.addAction(import_box_folder)
-        self.fileMenu.addAction(write_box_files)
+        write_menu = self.fileMenu.addMenu("&Write")
+        write_menu.addAction(write_box_files)
+        write_menu.addAction(write_star_files)
+
         self.fileMenu.addAction(close_action)
         self.image_folder = ""
 
@@ -287,11 +294,20 @@ class MainWindow(QtG.QMainWindow):
                 self.delete_all_patches(self.rectangles)
             else:
                 self.rectangles = []
-
+            prev_size = imagereader.read_width_height(self.current_image_path)
             self.current_image_path = os.path.join(self.image_folder, str(filename))
             self.fig.canvas.set_window_title(os.path.basename(self.current_image_path))
             img = self.read_image(self.current_image_path)
-            self.im.set_data(img)
+            prev_size = prev_size[::-1]
+            if prev_size == img.shape:
+                self.im.set_data(img)
+            else:
+                self.im = self.ax.imshow(
+                    img, origin="lower", cmap="gray", interpolation="Hanning"
+                )
+
+
+            self.plot.setWindowTitle(os.path.basename(self.current_image_path))
             self.fig.canvas.draw()
             self.background_current = self.fig.canvas.copy_from_bbox(self.ax.bbox)
             self.background_orig = self.fig.canvas.copy_from_bbox(self.ax.bbox)
@@ -402,8 +418,9 @@ class MainWindow(QtG.QMainWindow):
         import matplotlib as mpl
 
         estimated_size = []
-        for box in self.rectangles:
-            estimated_size.append(box.est_size)
+        for ident in self.box_dictionary:
+            for box in self.box_dictionary[ident]:
+                estimated_size.append(box.est_size)
         fig = plt.figure()
         # mpl.rcParams["figure.dpi"] = 200
         # mpl.rcParams.update({"font.size": 7})
@@ -518,11 +535,11 @@ class MainWindow(QtG.QMainWindow):
             if not self.filter_tuple_is_equal(self.get_filter_state(),state):
                 break
 
-    def write_box_files(self):
-        """
-        Write all files
-        :return: None
+    def write_coordinates(self,type):
         """
+              Write all files
+              :return: None
+              """
         box_dir = str(
             QtG.QFileDialog.getExistingDirectory(self, "Select Box Directory")
         )
@@ -541,6 +558,13 @@ class MainWindow(QtG.QMainWindow):
         pd.show()
         counter = 0
 
+        if type == "BOX":
+            file_ext = ".box"
+            write_coords_ = CoordsIO.write_eman1_boxfile
+        elif type == "STAR":
+            file_ext = ".star"
+            write_coords_ = CoordsIO.write_star_file
+
         for filename, rectangles in self.box_dictionary.items():
 
             if pd.wasCanceled():
@@ -551,22 +575,39 @@ class MainWindow(QtG.QMainWindow):
                 pd.setValue(val)
             QtCore.QCoreApplication.instance().processEvents()
 
-            box_filename = filename + ".box"
+            box_filename = filename + file_ext
             box_file_path = os.path.join(box_dir, box_filename)
             if self.is_cbox:
                 rectangles = [
                     box for box in rectangles if self.check_if_should_be_visible(box)
                 ]
-                #if self.use_estimated_size_checkbox.isChecked():
+                # if self.use_estimated_size_checkbox.isChecked():
             real_rects = [rect.getRect() for rect in rectangles]
             for rect in real_rects:
                 self.resize_box(rect, self.boxsize)
             num_writtin_part = num_writtin_part + len(real_rects)
-            CoordsIO.write_boxfile_manager(box_file_path, real_rects)
+
+            boxes = []
+            from cryolo.utils import BoundBox
+            for rect in real_rects:
+                x_lowerleft = int(rect.get_x())
+                y_lowerleft = int(rect.get_y())
+                boxize = int(rect.get_width())
+                box = BoundBox(x=x_lowerleft, y=y_lowerleft, w=boxize, h=boxize)
+                boxes.append(box)
+
+            write_coords_(box_file_path, boxes)
+
             self.unsaved_changes = False
             counter = counter + 1
         print(num_writtin_part, "particles written.")
 
+    def write_star_files(self):
+        self.write_coordinates(type="STAR")
+
+    def write_box_files(self):
+        self.write_coordinates(type="BOX")
+
     def load_box_files(self):
         self.is_cbox = False
         keep = False
@@ -626,7 +667,7 @@ class MainWindow(QtG.QMainWindow):
             )
             and os.stat(os.path.join(box_dir, f)).st_size != 0
         ]
-        colors = ["b", "g", "r", "c", "m", "y", "k", "w"]
+        colors = ["b", "r", "c", "m", "y", "k", "w"]
         if keep == False:
             rand_color = "r"
         else:
@@ -1046,7 +1087,6 @@ class MainWindow(QtG.QMainWindow):
                 self.fig.canvas.set_window_title(
                     os.path.basename(self.current_image_path)
                 )
-
                 # Display the image
                 self.im = self.ax.imshow(
                     im, origin="lower", cmap="gray", interpolation="Hanning"
@@ -1077,6 +1117,7 @@ class MainWindow(QtG.QMainWindow):
                 self.tree.setCurrentItem(
                     self.tree.invisibleRootItem().child(0).child(0)
                 )
+                self.plot.setWindowTitle(os.path.basename(self.current_image_path))
                 return True
             return False
 
@@ -1131,7 +1172,8 @@ class MainWindow(QtG.QMainWindow):
             return
 
         modifiers = QtG.QApplication.keyboardModifiers()
-        if event.xdata < 0 or event.ydata < 0:
+
+        if event.xdata is None or event.ydata is None or event.xdata < 0 or event.ydata < 0:
             return
         pure_filename = os.path.splitext(os.path.basename(self.current_image_path))[0]
 
